@@ -17,19 +17,22 @@
     trick: four  cards played which one pair wins:
     file_operations: a module to load or save events in a PBN, RBN or LIN format.
 """
+# from icecream import ic, install
+# ic.configureOutput(includeContext=True)
+# install()
 
-from bridgeobjects.source.constants import *
-from bridgeobjects.source.board import *
-from bridgeobjects.source.hand import *
-from bridgeobjects.source.card import *
-from bridgeobjects.source.suit import *
-from bridgeobjects.source.auction import *
-from bridgeobjects.source.contract import *
-from bridgeobjects.source.call import *
-from bridgeobjects.source.event import *
-from bridgeobjects.source.trick import *
-from bridgeobjects.source.file_operations import *
-from bridgeobjects.source.denomination import *  # type: ignore
+from bridgeobjects.constants import *
+from bridgeobjects.board import *
+from bridgeobjects.hand import *
+from bridgeobjects.card import *
+from bridgeobjects.suit import *
+from bridgeobjects.auction import *
+from bridgeobjects.contract import *
+from bridgeobjects.call import *
+from bridgeobjects.event import *
+from bridgeobjects.trick import *
+from bridgeobjects.file_operations import *
+from bridgeobjects.denomination import *
 
 from ._version import __version__
 VERSION = __version__
